Struct plaid::errors::PlaidError[][src]

pub struct PlaidError {
    pub error_type: String,
    pub error_code: String,
    pub error_message: String,
    pub display_message: Option<String>,
    pub request_id: String,
    pub status_code: StatusCode,
}

Fields

error_type: String

A broad categorization of the error. Safe for programatic use. Possible values: INVALID_REQUEST, INVALID_INPUT, INSTITUTION_ERROR, RATE_LIMIT_EXCEEDED, API_ERROR, ITEM_ERROR, ASSET_REPORT_ERROR, RECAPTCHA_ERROR, OAUTH_ERROR, PAYMENT_ERROR, BANK_TRANSFER_ERROR

error_code: String

The particular error code. Safe for programmatic use.

error_message: String

A developer-friendly representation of the error code. This may change over time and is not safe for programmatic use.

display_message: Option<String>

A user-friendly representation of the error code. None if the error is not related to user action. This may change over time and is not safe for programmatic use.

request_id: String

A unique identifying the request, to be used for troubleshooting purposes. This field will be omitted in errors provided by webhooks.

status_code: StatusCode

The HTTP status code associated with the error.