Struct plaid::errors::PlaidError [−][src]
Fields
error_type: StringA broad categorization of the error. Safe for programatic use. Possible values: INVALID_REQUEST, INVALID_INPUT, INSTITUTION_ERROR, RATE_LIMIT_EXCEEDED, API_ERROR, ITEM_ERROR, ASSET_REPORT_ERROR, RECAPTCHA_ERROR, OAUTH_ERROR, PAYMENT_ERROR, BANK_TRANSFER_ERROR
error_code: StringThe particular error code. Safe for programmatic use.
error_message: StringA developer-friendly representation of the error code. This may change over time and is not safe for programmatic use.
display_message: Option<String>A user-friendly representation of the error code. None if the error is not related to user action. This may change over time and is not safe for programmatic use.
request_id: StringA unique identifying the request, to be used for troubleshooting purposes. This field will be omitted in errors provided by webhooks.
status_code: StatusCodeThe HTTP status code associated with the error.